<?php

/**
 * This is the model class for table "agenti".
 *
 * The followings are the available columns in table 'agenti':
 * @property integer $idagente
 * @property integer $tocanc 
 * @property string $nome
 * @property string $cognome
 */
class Agenti extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'agenti';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('idagente', 'numerical', 'integerOnly'=>true),
			array('nome, cognome', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('idagente, nome, cognome', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			
			'idagente' => 'Id',
			'nome' => 'Nome',
			'cognome' => 'Cognome',
		);
	}


  public function getNextId()
  {
    $record=self::model()->find(array(
            'condition' => 'idagente>:current_id',
            'order' => 'idagente ASC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->idagente),
    ));
    if($record!==null)
        return $record->idagente;
    return null;
  }
  
  
  public function getPreviousId()
  {
    $record=self::model()->find(array(
            'condition' => 'idagente<:current_id',
            'order' => 'idagente DESC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->idagente),
    ));
    if($record!==null)
        return $record->idagente;
    return null;
  }
  
  
  public static function getOptions() {
   
      //$criteria=new CDbCriteria;
      //$criteria->select = 'id, nome, cognome';
      //$criteria->order = 'id';
      //$models = self::model()->findAll();
	  
	  //print_r($models[0]);
      /*$data = array();
      foreach($models as $model) {
         $data[$model->id] = $model->nome . ' '. $model->cognome;
      }*/
      //return CHtml::listData($models, 'id','nome');
	  
	   return CHtml::listData(Agenti::model()->findAll(array('order'=>'nome')), 'idagente', 'nomeCognome'); 
       
  }
  
  
   
  


  public function getNomeCognome(){
	  $concat = '';
	  if(isset($this->nome)) {
		  $concat .= $this->nome;
	  }
	  
	  if(isset($this->cognome)) {
		  $concat .= ' '.$this->cognome;
	  }
	  
      return $concat;
  }
  
  
  public static function getAgenteByPk($idagente) {
         $agente = self::model()->findByPk($idagente);
		 if(isset($agente->nome) && isset($agente->cognome)) {
			return $agente->cognome.' '.$agente->nome;
		 } else {
			 return '';
		 }
  }
  
  
  

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		//$criteria->compare('id-canc',$this->id);
		//$criteria->compare('idagente',$this->idagente);
		$criteria->compare('nome',$this->nome,true);
		$criteria->compare('cognome',$this->cognome,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'pagination' => array ('PageSize' => 20,),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Agenti the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
