<?php

/**
 * This is the model class for table "articoli".
 *
 * The followings are the available columns in table 'articoli':
 * @property integer $id
 * @property integer $idarticolo
 * @property string $cod
 * @property string $descrizione
 * @property double $prezzounitario
 * @property string $unitamisura
 * @property integer $conteggio
 */
class Articoli extends CActiveRecord
{
  public $quantita;
  public $tipologialavoro;
  public $unita;
  public $idordine;
  public $reparto;
  public $sconto;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'articoli';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('id, idarticolo, conteggio, quantita, tipologialavoro,idordine','numerical','integerOnly'=>true),
			array('prezzounitario, sconto', 'numerical'),
			array('cod, unitamisura, unita, reparto', 'length', 'max'=>50),
			array('descrizione', 'length', 'max'=>120),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, idarticolo, cod, descrizione, prezzounitario, unitamisura, conteggio', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'idarticolo' => 'Idarticolo',
			'cod' => 'Codice',
			'descrizione' => 'Descrizione',
			'prezzounitario' => 'Prezzo',
			'unitamisura' => 'Unit&agrave;',
			'conteggio' => 'Conteggio',
      'tipologialavoro'=>'Tip.Lavoro',
      'reparto'=>'Reparto',
      'sconto'=>'Sconto %',
		);
	}
  
  
  
  public function getNextId()
  {
    $record=self::model()->find(array(
            'condition' => 'id>:current_id',
            'order' => 'id ASC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  
  public function getPreviousId()
  {
    $record=self::model()->find(array(
            'condition' => 'id<:current_id',
            'order' => 'id DESC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  
  public static function getOptions() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, cod';
      $criteria->order = 'cod';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'cod','cod');
       
  }
  
  
   public function initsuggest($id)
  {
      $models=$this->findAll(array(
          'condition'=>'id LIKE :id',
          'params'=>array(':id'=>$id),
      ));
      $initsuggest=array();
      foreach($models as $model)
      {
          $initsuggest[] = array(
              'id'=>$model->id,
              'text'=>$model->cod,
          );
      }
      return $initsuggest;
  }
  
  
  
  
  
  public function suggest($keyword, $limit=20)
  {
      $models=$this->findAll(array(
          'condition'=>'cod LIKE :keyword',
          'params'=>array(':keyword'=>$keyword.'%'),
          'order'=>'cod',
          'limit'=>$limit,
      ));
      $suggest=array();
      foreach($models as $model)
      {
          $suggest[] = array(
              'id'=>$model->id,
              'text'=>$model->cod,
          );
      }
      return $suggest;
  }
  

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('idarticolo',$this->idarticolo);
		$criteria->compare('cod',$this->cod,true);
		$criteria->compare('descrizione',$this->descrizione,true);
		$criteria->compare('prezzounitario',$this->prezzounitario);
		$criteria->compare('unitamisura',$this->unitamisura,true);
		$criteria->compare('conteggio',$this->conteggio);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			 'pagination' => array ('PageSize' => 20,),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Articoli the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
