<?php

/**
 * This is the model class for table "clienti".
 *
 * The followings are the available columns in table 'clienti':
 * @property integer $id
 * @property integer $idcliente
 * @property string $nomeditta
 * @property string $indirizzo
 * @property string $piva
 * @property string $cap
 * @property string $citta
 * @property string $provincia
 * @property string $cellulare
 * @property string $telefono
 * @property string $fax
 * @property string $emai
 * @property string $internet
 * @property string $referente
 * @property string $note
 * @property string $pagamento
 * @property string $banca
 * @property string $agenzia
 * @property string $abi
 * @property string $cab
 * @property string $codfiscale
 * @property integer $riceveemail
 * @property double $costotrasporto
 * @property string $tipoconsegna
 */
class Clienti extends CActiveRecord
{
	public $maxColumn = 0;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'clienti';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('id, idcliente, riceveemail', 'numerical', 'integerOnly'=>true),
			array('costotrasporto', 'numerical'),
			array('nomeditta, indirizzo, telefono, fax, emai, internet', 'length', 'max'=>255),
			array('piva', 'length', 'max'=>11),
			array('cap', 'length', 'max'=>5),
			array('citta, cellulare, pagamento, banca, agenzia, abi, cab, tipoconsegna', 'length', 'max'=>50),
			array('provincia', 'length', 'max'=>2),
			array('referente', 'length', 'max'=>30),
			array('note', 'length', 'max'=>200),
			array('codfiscale', 'length', 'max'=>16),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, idcliente, nomeditta, indirizzo, piva, cap, citta, provincia, cellulare, telefono, fax, emai, internet, referente, note, pagamento, banca, agenzia, abi, cab, codfiscale, riceveemail, costotrasporto, tipoconsegna', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'idcliente' => 'Cod.',
			'nomeditta' => 'Nome Ditta',
			'indirizzo' => 'Indirizzo',
			'piva' => 'Piva',
			'cap' => 'Cap',
			'citta' => 'Citta',
			'provincia' => 'Provincia',
			'cellulare' => 'Cellulare',
			'telefono' => 'Telefono',
			'fax' => 'Fax',
			'emai' => 'Email',
			'internet' => 'Internet',
			'referente' => 'Referente',
			'note' => 'Note',
			'pagamento' => 'Pagamento',
			'banca' => 'Banca',
			'agenzia' => 'Agenzia',
			'abi' => 'Abi',
			'cab' => 'Cab',
			'codfiscale' => 'Cod.Fiscale',
			'riceveemail' => 'Riceve Email',
			'costotrasporto' => 'Costo Trasporto',
			'tipoconsegna' => 'Tipo Consegna',
		);
	}


  public function getNextId()
  {
    $record=self::model()->find(array(
            'condition' => 'id>:current_id',
            'order' => 'id ASC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  
  public function getPreviousId()
  {
    $record=self::model()->find(array(
            'condition' => 'id<:current_id',
            'order' => 'id DESC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  public function initsuggest($id)
  {
      $models=$this->findAll(array(
          'condition'=>'id LIKE :id',
          'params'=>array(':id'=>$id),
      ));
      $initsuggest=array();
      foreach($models as $model)
      {
          $initsuggest[] = array(
              'id'=>$model->id,
              'text'=>$model->nomeditta,
          );
      }
      return $initsuggest;
  }
  
  
  
  
  
  public function suggest($keyword, $limit=20)
  {
      $models=$this->findAll(array(
          'condition'=>'nomeditta LIKE :keyword',
          'params'=>array(':keyword'=>$keyword.'%'),
          'order'=>'nomeditta',
          'limit'=>$limit,
      ));
      $suggest=array();
      foreach($models as $model)
      {
          $suggest[] = array(
              'id'=>$model->id,
              'text'=>$model->nomeditta,
          );
      }
      return $suggest;
  }
  
  
  public static function renderNomeByPk($id) {
       $model = self::model()->find(array(
            'select'=>'nomeditta',
            'condition' => 'id=:id',
            'params'=>array(':id'=>$id),
       ));
       
       return $model['nomeditta'];
  
  }
  
  
  public static function renderReferenteByPk($id) { //Andrea 31/08/2014
       $model = self::model()->find(array(
            'select'=>'referente',
            'condition' => 'id=:id',
            'params'=>array(':id'=>$id),
       ));
       
       return $model['referente'];
  
  }  
  
  
   public static function getOptions() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, nomeditta';
      $criteria->order = 'nomeditta';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'id','nomeditta');
       
  }



	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('idcliente',$this->idcliente);
		$criteria->compare('nomeditta',$this->nomeditta,true);
		$criteria->compare('indirizzo',$this->indirizzo,true);
		$criteria->compare('piva',$this->piva,true);
		$criteria->compare('cap',$this->cap,true);
		$criteria->compare('citta',$this->citta,true);
		$criteria->compare('provincia',$this->provincia,true);
		$criteria->compare('cellulare',$this->cellulare,true);
		$criteria->compare('telefono',$this->telefono,true);
		$criteria->compare('fax',$this->fax,true);
		$criteria->compare('emai',$this->emai,true);
		$criteria->compare('internet',$this->internet,true);
		$criteria->compare('referente',$this->referente,true);
		$criteria->compare('note',$this->note,true);
		$criteria->compare('pagamento',$this->pagamento,true);
		$criteria->compare('banca',$this->banca,true);
		$criteria->compare('agenzia',$this->agenzia,true);
		$criteria->compare('abi',$this->abi,true);
		$criteria->compare('cab',$this->cab,true);
		$criteria->compare('codfiscale',$this->codfiscale,true);
		$criteria->compare('riceveemail',$this->riceveemail);
		$criteria->compare('costotrasporto',$this->costotrasporto);
		$criteria->compare('tipoconsegna',$this->tipoconsegna,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'pagination' => array ('PageSize' => 40,),
			'sort'=>array(
				'defaultOrder'=>'id DESC',
			),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Clienti the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
