<?php

/**
 * This is the model class for table "fornitori".
 *
 * The followings are the available columns in table 'fornitori':
 * @property integer $id
 * @property integer $IDfornitore
 * @property string $Nome
 * @property string $Categoria
 */
class Fornitori extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'fornitori';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('id, IDfornitore', 'numerical', 'integerOnly'=>true),
			array('Nome, Categoria', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, IDfornitore, Nome, Categoria', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'IDfornitore' => 'Idfornitore',
			'Nome' => 'Nome',
			'Categoria' => 'Categoria',
		);
	}


  public function getNextId()
  {
    $record=self::model()->find(array(
            'condition' => 'id>:current_id',
            'order' => 'id ASC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  
  public function getPreviousId()
  {
    $record=self::model()->find(array(
            'condition' => 'id<:current_id',
            'order' => 'id DESC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }


  public static function getOptionsGrafico() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, Nome';
      $criteria->condition = "Categoria = :categoria";
      $criteria->params = array (':categoria' => 'Grafica');
      $criteria->order = 'Nome';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'id','Nome');
       
  }
  
  
  public static function getOptionsStampa() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, Nome';
      $criteria->condition = "Categoria = :categoria";
      $criteria->params = array (':categoria' => 'Stampa');
      $criteria->order = 'Nome';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'id','Nome');
       
  }
  
  
  public static function getOptionsConfezione() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, Nome';
      $criteria->condition = "Categoria = :categoria";
      $criteria->params = array (':categoria' => 'Confezione');
      $criteria->order = 'Nome';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'id','Nome');
       
  }
  
  
  
  public static function renderNomeByPk($id) {
      if(!empty($id)) {
       $model = self::model()->find(array(
            'select'=>'Nome',
            'condition' => 'id=:id',
            'params'=>array(':id'=>$id),
       ));
       
       return $model['Nome'];
      } else {
          return 'Non assegnato';
      
      }

  }
  
  
  




	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('IDfornitore',$this->IDfornitore);
		$criteria->compare('Nome',$this->Nome,true);
		$criteria->compare('Categoria',$this->Categoria,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'pagination' => array ('PageSize' => 20,),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Fornitori the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
