<?php

/**
 * This is the model class for table "montaggio".
 *
 * The followings are the available columns in table 'montaggio':
 * @property integer $id
 * @property string $data
 * @property integer $id_montaggio_destinatario
 * @property integer $id_dipendente
 * @property string $data_consegna
 * @property integer $id_montaggio_stato
 * @property string $pdf
 * @property string $note
 * @property integer $id_montaggio_carta_sorgente
 */
class Montaggio extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'montaggio';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('data, data_consegna, pdf, note', 'required'),
			array('id_montaggio_destinatario, id_dipendente, id_montaggio_stato, id_montaggio_carta_sorgente', 'numerical', 'integerOnly'=>true),
			array('pdf', 'length', 'max'=>256),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, data, id_montaggio_destinatario, id_dipendente, data_consegna, id_montaggio_stato, pdf, note, id_montaggio_carta_sorgente', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'data' => 'Data',
			'id_montaggio_destinatario' => 'Id Montaggio Destinatario',
			'id_dipendente' => 'Id Dipendente',
			'data_consegna' => 'Data Consegna',
			'id_montaggio_stato' => 'Id Montaggio Stato',
			'pdf' => 'Pdf',
			'note' => 'Note',
			'id_montaggio_carta_sorgente' => 'Id Montaggio Carta Sorgente',
		);
	}
  
  
  public function renderReferente($data,$row) {
        
        if(isset($data->id_dipendente) && !empty($data->id_dipendente)) {
              
              $modeldipendente = Dipendenti::renderNomeByPk($data->id_dipendente);
              return $modeldipendente;
       } else {
          return '';
       }
  }
  
  
   public function renderMontaggioStato($data,$row) {
  
      if(isset($data->id_montaggio_stato) && !empty($data->id_montaggio_stato)) {
      
          $model = MontaggioStato::model()->findByPk($data->id_montaggio_stato);
          return $model['nome'];  
        
     }
     
   }
   
   
   public function renderFornitore($data,$row) {
       
     if(isset($data->id_montaggio_destinatario) && !empty($data->id_montaggio_destinatario)) {  
        return Fornitori::renderNomeByPk($data->id_montaggio_destinatario);
     }
   
   }
  
  
  

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('data',$this->data,true);
		$criteria->compare('id_montaggio_destinatario',$this->id_montaggio_destinatario);
		$criteria->compare('id_dipendente',$this->id_dipendente);
		$criteria->compare('data_consegna',$this->data_consegna,true);
		//$criteria->compare('id_montaggio_stato',$this->id_montaggio_stato);
    $criteria->addCondition('t.id_montaggio_stato <> 4');
		$criteria->compare('pdf',$this->pdf,true);
		$criteria->compare('note',$this->note,true);
		$criteria->compare('id_montaggio_carta_sorgente',$this->id_montaggio_carta_sorgente);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination' => array ('PageSize' => 40,),
      'sort'=>array(
        'defaultOrder'=>'t.id DESC',
      ),

		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Montaggio the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
