<?php

/**
 * This is the model class for table "ordini".
 *
 * The followings are the available columns in table 'ordini':
 * @property integer $id
 * @property integer $idordine
 * @property integer $codcliente
 * @property integer $utente_id 
 * @property string $datainserimento
 * @property string $dataconsegna
 * @property string $stato
 * @property string $tipoconsegna
 * @property integer $dapreventivare
 * @property string $nota
 * @property string $documento
 * @property string $dataconsegnato
 * @property integer $agente
 * @property integer $consegnatassativa
 * @property double $costotrasporto
 * @property integer $archivio
 * @property integer $iddocref
 * @property string $firma
 * @property integer $visprezzi
 * @property integer $vistotali
 * @property integer $esportato
 * @property string $tipologiaordine
 */
class Ordini extends CActiveRecord
{ 
  public $post_count;
  public $recenti;
  public $ordinamento;
  public $nomecli;
  public $anchearchiviati;
  public $maxColumn;
  public $nomeditta_search;
  public $referente;
  public $datains = array();
  public $_totali = 0;
  
  
  public function getTotali(){
    //return $this->surname . ', ' . $this->firstname;
	return $this->getTotals($this->idordine); 
  }
  
  
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'ordini';
	}
	
	
	/* behaviors */
	public function behaviors()
	{
		return array(
			'dateRangeSearch'=>array(
				'class'=>'application.components.EDateRangeSearchBehavior',
			),
			
		);
	}
	

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('datainserimento, dataconsegna', 'required'),
			array('id, idordine, codcliente, dapreventivare, agente, consegnatassativa, archivio, iddocref, visprezzi, vistotali, esportato', 'numerical', 'integerOnly'=>true),
			array('costotrasporto,utente_id', 'numerical'),
			array('totali', 'numerical', 'allowEmpty' => true,'integerOnly' => false),
			array('inviatopreventivo', 'numerical', 'allowEmpty' => false,'integerOnly' => true),
			array('stato, tipoconsegna', 'length', 'max'=>50),
			array('nota, documento, tipologiaordine', 'length', 'max'=>255),
			array('firma', 'length', 'max'=>64),
			array('dataconsegna, dataconsegnato', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, idordine, codcliente, datainserimento, dataconsegna, stato, tipoconsegna, dapreventivare, nota, documento, dataconsegnato, agente, consegnatassativa, costotrasporto, archivio, iddocref, firma, visprezzi, vistotali, esportato, tipologiaordine, c, nomeditta_search, referente', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.   
		return array(
			'relcliente'=>array(self::HAS_ONE,'Clienti', array('id'=>'codcliente')),
			'relnotifiche'=>array(self::HAS_ONE,'Notifiche', array('idordine'=>'id')),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'idordine' => 'n.ordine',
			'codcliente' => 'Cliente',
			'utente_id' => 'User',
			'datainserimento' => 'Data inserimento',
			'dataconsegna' => 'Data consegna',
			'stato' => 'Stato',
			'tipoconsegna' => 'Tipo consegna',
			'dapreventivare' => 'Da preventivare',
			'nota' => 'Nota',
			'documento' => 'Documento',
			'dataconsegnato' => 'Data consegnato',
			'agente' => 'Agente',
			'consegnatassativa' => 'Tassativa',
			'costotrasporto' => 'Costo trasporto',
			'archivio' => 'Archivio',
			'iddocref' => 'Iddocref',
			'firma' => 'Firma',
			'visprezzi' => 'Visprezzi',
			'vistotali' => 'Vistotali',
			'esportato' => 'Esportato',
			'tipologiaordine' => 'Tipo Ordine',
			'ordinamento' => 'Ordina per...',
			'inviatopreventivo'=>'Preventivo',
		);
	}
  
  
  public function getNextId()
  {
    $record=self::model()->find(array(
            'condition' => 'id>:current_id',
            'order' => 'id ASC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  
  public function getPreviousId()
  {
    $record=self::model()->find(array(
            'condition' => 'id<:current_id',
            'order' => 'id DESC',
            'limit' => 1,
            'params'=>array(':current_id'=>$this->id),
    ));
    if($record!==null)
        return $record->id;
    return null;
  }
  
  public function getTotals($idordine)
  {
      
     if(isset($idordine)) {           
        $connection=Yii::app()->db;
        $command=$connection->createCommand("SELECT SUM(prezzounitario * quantita) - SUM(prezzounitario * quantita * sconto / 100) FROM `lavori` WHERE idordine = ".$idordine);
        $amount = $command->queryScalar();
        return number_format((float)$amount,2,'.','');
		//return (float)$amount;
     } else {
        return '';
     
     }
  } 
  
  
  public function getCostotrasporto() {
	  return $this->costotrasporto;
  }

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		

	$criteria=new CDbCriteria;
    $criteria->with = array('relcliente');
     // sub query to retrieve the count of posts
    /*$post_table = Lavori::model()->tableName();
    $post_count_sql = "(select count(*) from $post_table pt where pt.idordine = t.id)";
 
  
    $criteria->select = array(
        '*',
        $post_count_sql . " as post_count",
    );

    $criteria->compare($post_count_sql, '>0');
	*/
	$criteria->compare('idordine',$this->idordine);
	$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
	$criteria->compare('relcliente.referente', $this->referente, true);		
	$criteria->compare('nota',$this->nota,true);
    $criteria->addCondition('archivio = "0" AND dapreventivare = "0" AND (t.stato = "Inserito" OR t.stato = "Avanzamento" OR t.stato = "Pronto")');

	return new CActiveDataProvider($this, array(
		'criteria'=>$criteria,
		'pagination' => array ('PageSize' => 40,),
		'sort'=>array(
			'defaultOrder'=>'t.id DESC',
			'attributes'=>array(
				'nomeditta_search'=>array(
					'asc'=>'relcliente.nomeditta',
					'desc'=>'relcliente.nomeditta DESC',
				),
				'referente'=>array(
					'asc'=>'relcliente.referente',
					'desc'=>'relcliente.referente DESC',
				),
				
				'*',
			),
		),
	));
	
	}

	
	
	
	/* Andrea - creo una seconda funzione in grado di evidenziare solo quelli da confermare */
	public function searchDaconfermare()
	{
	$criteria=new CDbCriteria;
    $criteria->with = array('relcliente');
	
	if($this->idordine != 0) {
		$criteria->compare('t.idordine',$this->idordine);
	}
	$criteria->compare('t.nota',$this->nota,true);
	$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
	$criteria->compare('relcliente.referente', $this->referente, true);		
	$criteria->addCondition('t.archivio = "0" AND t.dapreventivare = "0" AND t.stato="Attesa"');

	return new CActiveDataProvider($this, array(
	  'criteria'=>$criteria,
      'pagination' => array ('PageSize' => 40,),
      'sort'=>array(
      'defaultOrder'=>'t.id DESC',
	  'attributes'=>array(
					'nomeditta_search'=>array(
						'asc'=>'relcliente.nomeditta',
						'desc'=>'relcliente.nomeditta DESC',
					),
					'referente'=>array(
						'asc'=>'relcliente.referente',
						'desc'=>'relcliente.referente DESC',
					),
					'*',
				),
      ),
		));
	}
	
	
	
	
	/* Andrea - creo una seconda funzione in grado di evidenziare solo quelli da preventivare */
	public function searchPreventivare()
	{
	$criteria=new CDbCriteria;
    $criteria->with = array('relcliente');///*
    $post_table = Lavori::model()->tableName();
    $post_count_sql = "(select count(*) from $post_table pt where pt.idordine = t.id)";
 
    $criteria->select = array(
        '*',
        $post_count_sql . " as post_count",
    );

    $criteria->compare($post_count_sql, '>0');//*/
	$criteria->compare('idordine',$this->idordine);
	$criteria->compare('dapreventivare','1');
	$criteria->compare('nota',$this->nota,true);
	$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
	$criteria->compare('relcliente.referente', $this->referente, true);		
    $criteria->addCondition('archivio = "0" AND dapreventivare = "1" AND t.stato="Inserito" AND t.dataconsegna >= DATE_SUB(NOW(), INTERVAL 60 DAY)');// AND (t.stato = "Inserito" OR t.stato = "Avanzamento" OR t.stato = "Pronto")');

	return new CActiveDataProvider($this, array(
		'criteria'=>$criteria,
		'pagination' => array ('PageSize' => 40,),
		'sort'=>array(
				'defaultOrder'=>'t.id DESC',
				'attributes'=>array(
					'nomeditta_search'=>array(
						'asc'=>'relcliente.nomeditta',
						'desc'=>'relcliente.nomeditta DESC',
					),
					'referente'=>array(
						'asc'=>'relcliente.referente',
						'desc'=>'relcliente.referente DESC',
					),
					'*',
				),
		),
	));
}
	
	/* Andrea creo una funzione in grado di evidenziare solo gli ordini da consegnare */
	public function searchConsegne()
	{
		
	
		$criteria=new CDbCriteria(array(
									'condition'=>'t.archivio = "0" AND t.dapreventivare="0" And t.stato="Pronto"',
									'with'=>'relcliente',
									'together'=>true,
		));
		
		
		if($this->idordine != 0) {
			$criteria->compare('t.idordine',$this->idordine);
		}
		
		$criteria->compare('nota',$this->nota,true);
		
		if(isset($this->tipologiaordine)) {
			$criteria->addCondition("t.tipologiaordine Like '%" . $this->tipologiaordine . "%'");
		}

		if (isset($this->recenti) And $this->recenti=='0' And $this->recenti!='' ) {
		} else {
			$criteria->addCondition("t.dataconsegna > '2014-03-01'");
		}
	   
		if (isset($this->stato)) {
			$criteria->addCondition("t.stato = '" .$this->stato. "' ");
		} 	

		$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);	
		$criteria->compare('relcliente.referente', $this->referente, true);		
	   
		return new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination'=>array('pageSize'=>60),
			'sort'=>array(
				'defaultOrder'=>'t.id DESC',
				'attributes'=>array(
					'nomeditta_search'=>array(
						'asc'=>'relcliente.nomeditta',
						'desc'=>'relcliente.nomeditta DESC',
					),
					'referente'=>array(
						'asc'=>'relcliente.referente',
						'desc'=>'relcliente.referente DESC',
					),
					'*',
				),
			),
		));


	}
	



	
	/* Andrea 02/11/2014 - Ricerca  per nome cliente */
	public function searchCliente()
	{
		
	
		$criteria=new CDbCriteria(array(
									
									'with'=>'relcliente',
									'together'=>true,
									/* 'limit'=>100, */
		));
		//print_r($this->datains);
		if(count($this->datains) > 0) {
			$criteria->mergeWith($this->dateRangeSearchCriteria('t.datainserimento', $this->datains));  
		}
		if($this->idordine != 0) {
			$criteria->compare( 'idordine', $this->idordine, false );
		}
		$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
		$criteria->compare('relcliente.referente', $this->referente, true);
		$criteria->compare('nota', $this->nota, true);
		$criteria->compare('dapreventivare', $this->dapreventivare, true);
		
		$criteria->addCondition("t.stato <> 'Draft'");
		$criteria->addCondition("t.stato <> 'Consegnato'");
		$criteria->addCondition("t.datainserimento > '".date('Y')."-01-01'");
		
		if (isset($this->anchearchiviati)) {
			
		} else {
			$criteria->addCondition("t.archivio = 0");
		}
		
		
		
   
		$dataProvider=new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination' => array ('PageSize' => 50,),
			'sort'=>array(
				'defaultOrder'=>'t.id DESC',
				'attributes'=>array(
					/*'nomeditta_search'=>array(
							'asc'=>'relcliente.nomeditta',
							'desc'=>'relcliente.nomeditta DESC',
					),*/
					'totali'=>array('asc' => SORT_ASC,
							'desc' => SORT_DESC,
							),
							
					/*'totali'=>array('asc' => 'totali asc',
							    'desc'=>'totali desc',
							),*/
							


					
					
                
					
					
					'*',
				),
			),
			
		));
		return $dataProvider;
	}
	
	
	
	
	/* Andrea 02/11/2014 - Ricerca  per nome cliente */
	public function searchClienteallordini()
	{
		
		$criteria=new CDbCriteria(array('with'=>'relcliente','together'=>true,));

		if(count($this->datains) > 0) {
			$criteria->mergeWith($this->dateRangeSearchCriteria('t.datainserimento', $this->datains));  
		}
		if($this->idordine != 0) {
			$criteria->compare( 'idordine', $this->idordine, false );
		}
		$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
		$criteria->compare('relcliente.referente', $this->referente, true);
		$criteria->compare('nota', $this->nota, true);
		$criteria->compare('dapreventivare', $this->dapreventivare, true);
		
		$criteria->addCondition("t.stato <> 'Draft'");
		//$criteria->addCondition("t.stato <> 'Consegnato'");
   
		$dp=new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination' => array ('PageSize' => 50,),
			'sort'=>array(
				'defaultOrder'=>'t.id DESC',
				'attributes'=>array(
					'totali'=>array(
						'asc' => SORT_ASC,
						'desc' => SORT_DESC,
					),
					'*',
				),
			),
			
		));
		return $dp;
	}
	

	
	public function searchOrdiniconsegnati() {
		
		$criteria=new CDbCriteria(array('with'=>'relcliente','together'=>true,'order'=>'t.id DESC'));
		$criteria->addCondition("t.stato = 'Consegnato'");	
		return new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination'=>array('pageSize'=>60),
		));
	
	}
	
	
	
		/* Andrea 02/11/2014 - Ricerca  per nome cliente */
	public function searchMyOrdini()
	{
		$clausolaorderby = 't.id DESC';
		/* 'condition'=>'dataconsegna BETWEEN DATE_SUB(NOW(), INTERVAL 90 DAY) AND NOW()', */
		$criteria=new CDbCriteria(array(
									
									'with'=>'relcliente',
									'together'=>true,
									'order'=>$clausolaorderby,
								
		));
		
		
		if($this->idordine != 0) {
			$criteria->compare( 'idordine', $this->idordine, false );
		}
		$criteria->compare('relcliente.nomeditta', $this->nomeditta_search, true);
		$criteria->compare('relcliente.referente', $this->referente, true);
		//'filter' => CHtml::activeTextField($model, 'nomeditta_search'),
		$criteria->compare('nota', $this->nota, true);
		$criteria->compare('agente', $this->agente, false);
		
		$criteria->addCondition("t.stato <> 'Draft'");
		
		
		
		
   
		$dataProvider=new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination'=>false,
			'sort'=>array(
				'attributes'=>array(
					'nomeditta_search'=>array(
						'asc'=>'relcliente.nomeditta',
						'desc'=>'relcliente.nomeditta DESC',
					),
					'referente'=>array(
						'asc'=>'relcliente.referente',
						'desc'=>'relcliente.referente DESC',
					),
					'*',
				),
			),
		));
		return $dataProvider;
	}
	
	
	
	
	/* Andrea 28/12/2014 - Ricerca  per nome cliente da Conf*/
	public function searchClientedaconf()
	{
		$clausolaorderby = 'dataconsegna DESC';
		$criteria=new CDbCriteria(array(
									'condition'=>'',
									'with'=>'relcliente',
									'together'=>true,
									'order'=>$clausolaorderby,
		));
		
       $criteria->addCondition('archivio = "0" AND dapreventivare = "0" AND stato = "Attesa" ');		
		if (isset($this->nomecli)) {
			$criteria->addCondition("relcliente.nomeditta Like '%".$this->nomecli."%' ");
		}

		$dataProvider=new CActiveDataProvider('Ordini',array(
			'criteria'=>$criteria,
			'pagination'=>array('pageSize'=>60),
		));
		return $dataProvider;
	}	
	
	
	public function renderNoteGriglia($data,$row) {
		if(isset($data->nota)) {
			//return preg_replace("/([\x80-\xFF])/e","chr(0xC0|ord('\\1')>>6).chr(0x80|ord('\\1')&0x3F)",);
			//$text = mb_substr(, 0,34);
			$enc = mb_detect_encoding($data->nota, "UTF-8,ISO-8859-1");
			return mb_strtolower(mb_substr(iconv($enc, "UTF-8", $data->nota),0,34,"UTF-8"),'UTF-8');
		}
	}
	
	
	public function renderButtons($data,$row) {
		
		$htmlbuttons = '';
		$htmlbuttons .= '<a href="javascript:eventButtonPreventivo('.$data->id.',this);" title="Stampa Preventivo"><img src="images/printButton.png" border="0" alt="Preventivo" /></a>';
		$htmlbuttons .= '&nbsp;&nbsp;';
		if(isset($data->relcliente->nomeditta) && isset($data->id)) {
			$htmlbuttons .= '<a href="#previewEmail" role="button" onclick="js:$(\'#callbackstatus\').html(\'\'); $(\'#inviaemailbutton\').css(\'display\',\'\'); $(\'#previewEmail\').modal(\'show\'); $(\'#modalnomeaz\').html(\''.$data->relcliente->nomeditta.'\'); $(\'#modalreferente\').html(\''.$data->relcliente->referente.'\'); $(\'#modalemail\').val(\''.$data->relcliente->emai.'\'); $(\'#modalid\').val(\''.$data->id.'\'); $(\'#modalurl\').attr(\'href\',\'index.php?r=ordini/printpdfpreventivo&id='.$data->id.'\');" title="'.($data->inviatopreventivo?"Preventivo inviato il ".date('d-m-Y H:i:s',strtotime($data->datainvio)):"Invia preventivo").'">'.($data->inviatopreventivo?"<img src='images/check.png' border='0' title='' alt='Preventivo inviato' />":"<i class='icon-envelope' style=''></i>").'</a>';
			
			$htmlbuttons .= '&nbsp;&nbsp;';
		} else {
			$htmlbuttons .= '<i class="icon-envelope"></i>&nbsp;&nbsp;';
		}
		
		$htmlbuttons .= '<a href="javascript:eventButtonStampa('.$data->id.',this);" title="Stampa Ordine"><img src="images/stampa.png" border="0" alt="Stampa" /></a>';
		$htmlbuttons .= '&nbsp;&nbsp;';
		//$htmlbuttons .= '<a href="javascript:eventButtonModifica('.$data->id.',this);" title="Modifica"><img src="images/modifica.png" border="0" alt="Modifica" /></a>';		
		//$htmlbuttons .= '&nbsp;&nbsp;';
		
		if(Yii::app()->user->getIsAdmin()) {
		
			$htmlbuttons .= '<a href="javascript:eventButtonClona('.$data->id.',this);" title="Clona Ordine"><i class="icon-file"></i></a>';
			$htmlbuttons .= '&nbsp;&nbsp;'; 
			
			if($data->stato=="Pronto") {
				$htmlbuttons .= '<img src="images/clock_green.png" border="0" alt="Pronto" width="16" class="clockgreen" />';				
			} else {
				$htmlbuttons .= '<a class="pronto" target="_blank" href="'.Yii::app()->createUrl('ordini/setStatoProntoAll',array('id'=>$data->idordine)).'" title="Pronto per consegna"><img src="'.Yii::app()->request->baseUrl.'/images/clock.png" border="0" alt="Pronto per consegna" /></a>';							
			}
			
			$htmlbuttons .= '&nbsp;&nbsp;';
			if($data->stato=="Pronto") {
				$htmlbuttons .= '<a target="_blank" href="javascript:eventButtonConsegnato('.$data->id.',this);" title="Consegna"><img src="images/consegna.png" border="0" alt="Consegna" /></a>';
			} else {
				$htmlbuttons .= '<img src="images/consegna_opaco.png" border="0" alt="Consegnato" width="16" class="clockgreen"  title="Consegnato"/>';				
			}
			
			$htmlbuttons .= '&nbsp;&nbsp;';
			
			
			if($data->stato=="Pronto") {
				$htmlbuttons .= '<a class="esportabutton" target="_blank" href="'.Yii::app()->createUrl("ordini/exportordine", array("id"=>"$data->idordine")).'" title="Esporta"><img src="images/export.gif" border="0" alt="Esporta" /></a>';
			} else {
				$htmlbuttons .= '<img src="images/export_opaco.png" border="0" width="16" class="clockgreen" />';				
			}
		
		
		}
		
		return $htmlbuttons;
		
	}
	
	public function renderButtonModify($data,$row) {
		
		$htmlbuttons = '';
		$htmlbuttons .= '<a href="javascript:eventButtonModifica('.$data->id.',this);" title="Modifica"><img src="images/modifica.png" border="0" alt="Modifica" /></a>';		
		return $htmlbuttons;
		
	}
	

	
	
	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Ordini the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
