<?php

/**
 * This is the model class for table "utenti".
 *
 * The followings are the available columns in table 'utenti':
 * @property string $idutente
 * @property string $nome
 * @property string $cognome
 * @property string $mail
 * @property string $cellulare
 * @property string $idagente 
 */
class Utenti extends CActiveRecord
{
  public $concatnomecognome;
  const LEVEL_AGENTE=1, LEVEL_SUPERAGENTE=6, LEVEL_ADMIN=99, LEVEL_SUPERADMIN=100;
 
 /**
  * define the label for each level
  * @param int $level the level to get the label or null to return a list of labels
  * @return array|string
  */
 static function getAccessLevelList( $level = null ){
    $levelList=array(
     self::LEVEL_AGENTE => 'Agente',
     self::LEVEL_SUPERAGENTE => 'Responsabile',
     self::LEVEL_ADMIN => 'Administrator',
     self::LEVEL_SUPERADMIN=>'Super Administrator',
    );
    if( $level === null)
     return $levelList;
    return $levelList[ $level ];
 } 
  
  
  public function renderRuolo($data,$row) {
  
  
         if(isset($data->ruolo) && !empty($data->ruolo)) {
            return self::getAccessLevelList($data->ruolo);
         } else {
            return '';
         }
         
         
          
          
  }  
  
  
  
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Utenti the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'utenti';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('nome, cognome, mail, cellulare', 'required'),
			array('nome, cognome, cellulare', 'length', 'max'=>150),
			array('username, password', 'length', 'max'=>255),
			array('ruolo', 'length', 'max'=>2),
			array('gruppo', 'length', 'max'=>20),
			array('block', 'length', 'max'=>1),
			array('mail', 'length', 'max'=>100),
			array('idagente','numerical','integerOnly'=>true),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('idutente, nome, cognome, mail, cellulare, gruppo', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		
		return array(
			'idutente' => 'Id',
			'nome' => 'Nome',
			'cognome' => 'Cognome',
			'mail' => 'Mail',
			'cellulare' => 'Cellulare',
			'gruppo' => 'Gruppo',
			'idagente'=>'Agente',
		);


	}
  
  
  /*
  public static function getOptions() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'idutente, nome, cognome, CONCAT(nome," ",cognome) as concatnomecognome';
      $criteria->order = 'nome';
      $criteria->condition = 'ruolo != "100"';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'idutente','concatnomecognome');
       
  }
  */

   public static function getOptions() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'idutente, nome, cognome, CONCAT(nome," ",cognome) as concatnomecognome';
      $criteria->order = 'nome';
      $criteria->condition = 'ruolo != "100"';
      $models = self::model()->findAll($criteria);
      return CHtml::listData($models, 'idutente','concatnomecognome');
       
  }
  
  
   public static function getOptionsAgenti() {
   
      $criteria=new CDbCriteria;
      $criteria->select = 'id, nome, cognome, CONCAT(nome," ",cognome) as concatnomecognome';
      $criteria->order = 'nome';
      
      $models = Agenti::model()->findAll($criteria);
      return CHtml::listData($models, 'id','concatnomecognome');
       
  }
  
  
  
  
  public static function renderNameById($id) {
        $model = self::model()->findByPk($id);
        
        if(!isset($model->nome)) {
           $model->nome = '';
        }
        
        if(!isset($model->cognome)) {
           $model->cognome = '';
        }
        
        return $model->nome.' '.$model->cognome;
  }
  
  
  public static function renderOnlyNameById($id) {
  
        $model = self::model()->findByPk($id);
        
        if(!isset($model->nome)) {
           $model->nome = '';
        }
        
               
        return $model->nome;
  }
  
  
	public function getFullName() {
		if(!isset($this->nome)) {
           $this->nome = '';
		}
        
        if(!isset($model->cognome)) {
           $this->cognome = '';
        }
        
        return $this->nome.' '.$this->cognome;
	}

	public function getSuggest($q) {
		$c = new CDbCriteria();
		$c->addSearchCondition('username', $q, true, 'OR');
		$c->addSearchCondition('mail', $q, true, 'OR');
		return $this->findAll($c);
	}
  
  
  
	public function suggest($keyword, $limit=20)
  {
	  $c = new CDbCriteria();
	  $c->addSearchCondition('nome', $keyword, true, 'OR');
	  $c->addSearchCondition('cognome', $keyword, true, 'OR');
	  $c->limit = $limit;
	  $c->order = 'cognome';
      $models=$this->findAll($c);
      $suggest=array();
	  
      foreach($models as $model)
      {
          $suggest[] = array(
              'id'=>$model->idutente,
              'text'=>$model->cognome.' '.$model->nome,
          );
      }
      return $suggest;
  }
  
  
   public function initsuggest($id)
  {
      $models=$this->findAll(array(
          'condition'=>'id LIKE :id',
          'params'=>array(':id'=>$id),
      ));
      $initsuggest=array();
      foreach($models as $model)
      {
          $initsuggest[] = array(
              'id'=>$model->idutente,
              'text'=>$model->cognome.' '.$model->nome,
          );
      }
      return $initsuggest;
  }

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('idutente',$this->idutente,true);
		$criteria->compare('nome',$this->nome,true);
		$criteria->compare('cognome',$this->cognome,true);
		$criteria->compare('mail',$this->mail,true);
		$criteria->compare('cellulare',$this->cellulare,true);
		$criteria->compare('gruppo',$this->gruppo,false);
		$criteria->addCondition('t.ruolo NOT LIKE "100"','AND');

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination' => array ('pageSize' => 30),
		));
	}
}
